@@ -23,9 +23,11 @@
 #define SCIM_TOMOE_CONFIG_USE_AUTO_FIND           "/Helper/Tomoe/UseAutoFind"
 #define SCIM_TOMOE_CONFIG_AUTO_FIND_TIME          "/Helper/Tomoe/AutoFindTime"
 #define SCIM_TOMOE_CONFIG_CLEAR_ON_SELECT         "/Helper/Tomoe/ClearOnSelect"
+#define SCIM_TOMOE_CONFIG_WINDOW_ALWAYS_TOP       "/Helper/Tomoe/AlwaysTop"
 
-#define SCIM_TOMOE_CONFIG_USE_AUTO_FIND_DEFAULT   true
-#define SCIM_TOMOE_CONFIG_AUTO_FIND_TIME_DEFAULT  0
-#define SCIM_TOMOE_CONFIG_CLEAR_ON_SELECT_DEFAULT false
+#define SCIM_TOMOE_CONFIG_USE_AUTO_FIND_DEFAULT     true
+#define SCIM_TOMOE_CONFIG_AUTO_FIND_TIME_DEFAULT    0
+#define SCIM_TOMOE_CONFIG_CLEAR_ON_SELECT_DEFAULT   false
+#define SCIM_TOMOE_CONFIG_WINDOW_ALWAYS_TOP_DEFAULT false
 
 #endif /* __SCIM_TOMOE_PREFS_H__ */
